@@ -37,7 +37,7 @@ ContingencyLBModel_mu_i_nu_j::ContingencyLBModel_mu_i_nu_j(MatrixReal const& m_D
   DataSum_ = m_Dataij.sum();
 };
 
-ContingencyLBModel_mu_i_nu_j::ContingencyLBModel_mu_i_nu_j(MatrixReal const& m_Dataij,VectorInteger const & rowlabels,VectorInteger const & collabels,
+ContingencyLBModel_mu_i_nu_j::ContingencyLBModel_mu_i_nu_j(MatrixReal const& m_Dataij,VectorInt const & rowlabels,VectorInt const & collabels,
                                                            VectorReal const& v_Mui,VectorReal const& v_Nuj,ModelParameters const& Mparam)
                              : ICoClustModel(Mparam,rowlabels,collabels)
                              , m_Dataij_(m_Dataij),v_Mui_(v_Mui),v_Nuj_(v_Nuj)
@@ -134,7 +134,7 @@ bool ContingencyLBModel_mu_i_nu_j::initCEMRows()
   v_Tk_.resize(Mparam_.nbrowclust_) = 0;
 
   m_Rjl_.resize(nbVar_,Mparam_.nbcolclust_) = 0;
-  v_Rl_ = STK::Const::Vector<STK::Real>(cols);
+  v_Rl_ = STK::Const::VectorX(cols);
 
   // Initializations. m_Uil_ will contain cols columns of the original data set
   m_Uil_.resize(nbSample_, cols) = 0;
@@ -340,7 +340,7 @@ bool ContingencyLBModel_mu_i_nu_j::initEMRows()
   v_Tk_.resize(Mparam_.nbrowclust_) = 0;
 
   m_Rjl_.resize(nbVar_,Mparam_.nbcolclust_) = 0;
-  v_Rl_ = STK::Const::Vector<STK::Real>(cols);
+  v_Rl_ = STK::Const::VectorX(cols);
 
   // Initializations. m_Uil_ will contain cols columns of the original data set
   m_Uil_.resize(nbSample_, cols) = 0;
@@ -591,7 +591,7 @@ void ContingencyLBModel_mu_i_nu_j::selectRandomColsFromData(MatrixReal& _m_il,in
   else
   {
     //random shuffle Algorithm
-    VectorInteger _v_temp(Mparam_.nbcoldata_);
+    VectorInt _v_temp(Mparam_.nbcoldata_);
     for ( int j = 0; j < Mparam_.nbcoldata_; ++j) { _v_temp[j]=j;}
     for ( int l = 0; l < cols; ++l)
     {
@@ -612,7 +612,7 @@ void ContingencyLBModel_mu_i_nu_j::selectRandomColsFromData(MatrixReal& _m_il,in
 void ContingencyLBModel_mu_i_nu_j::randomPoissonParameterRows(MatrixReal& m_kl,int cols)
 {
   // sample nbrowclust_ integer form [1..nbSample]
-  VectorInteger _v_temp = randSample(nbSample_, Mparam_.nbrowclust_);
+  VectorInt _v_temp = randSample(nbSample_, Mparam_.nbrowclust_);
   for ( int k = 0; k < Mparam_.nbrowclust_; ++k)
   {
     int index=_v_temp[k];
@@ -625,7 +625,7 @@ void ContingencyLBModel_mu_i_nu_j::randomPoissonParameterRows(MatrixReal& m_kl,i
 
 void ContingencyLBModel_mu_i_nu_j::randomPoissonParameterCols(MatrixReal& m_lk)
 {
-  VectorInteger _v_temp = randSample(nbVar_,Mparam_.nbcolclust_);
+  VectorInt _v_temp = randSample(nbVar_,Mparam_.nbcolclust_);
   for ( int l = 0; l < Mparam_.nbcolclust_; ++l)
   {
     int index=_v_temp[l];
@@ -640,14 +640,14 @@ void ContingencyLBModel_mu_i_nu_j::randomPoissonParameterCols(MatrixReal& m_lk)
 
 void ContingencyLBModel_mu_i_nu_j::logSumRows(MatrixReal & m_ik)
 {
-  m_ik = STK::Const::Vector<STK::Real>(nbSample_)*v_logPiek_.transpose() +
+  m_ik = STK::Const::VectorX(nbSample_)*v_logPiek_.transpose() +
       m_Uil_*((m_Gammakl_.log()).transpose())
       -v_Mui_*(m_Gammakl_*v_nul_).transpose();
 }
 
 void ContingencyLBModel_mu_i_nu_j::logSumCols(MatrixReal & m_jl)
 {
-  m_jl = STK::Const::Vector<STK::Real>(nbVar_)*v_logRhol_.transpose() + m_Vjk_*((m_Gammakl_.log()))
+  m_jl = STK::Const::VectorX(nbVar_)*v_logRhol_.transpose() + m_Vjk_*((m_Gammakl_.log()))
       -v_Nuj_*(v_muk_.transpose()*m_Gammakl_);
 }
 
@@ -681,8 +681,8 @@ bool ContingencyLBModel_mu_i_nu_j::randomInit()
   std::cout<<"Entering ContingencyLBModel_mu_i_nu_j::randomInit()."<<"\n";
 #endif
   //Initialize random row and column partition
-  VectorReal probarows = (1.0/Mparam_.nbrowclust_)*STK::Const::Vector<STK::Real>(Mparam_.nbrowclust_);
-  VectorReal probacols = (1.0/Mparam_.nbcolclust_)*STK::Const::Vector<STK::Real>(Mparam_.nbcolclust_);
+  VectorReal probarows = (1.0/Mparam_.nbrowclust_)*STK::Const::VectorX(Mparam_.nbrowclust_);
+  VectorReal probacols = (1.0/Mparam_.nbcolclust_)*STK::Const::VectorX(Mparam_.nbcolclust_);
   v_Zi_ = partRnd(nbSample_,probarows);
   v_Wj_ = partRnd(nbVar_,probacols);
   m_Zik_.resize(nbSample_,Mparam_.nbrowclust_) = 0;
@@ -725,8 +725,8 @@ bool ContingencyLBModel_mu_i_nu_j::randomInit()
   v_Tk_.resize(Mparam_.nbrowclust_) = 0;
   v_Zi_.resize(nbSample_) = 0;
   v_Wj_.resize(nbVar_) = 0;
-  v_logPiek_ = std::log(1.0/Mparam_.nbrowclust_)*(STK::Const::Vector<STK::Real>(Mparam_.nbrowclust_));
-  v_logRhol_ = std::log(1.0/Mparam_.nbcolclust_)*(STK::Const::Vector<STK::Real>(Mparam_.nbcolclust_));
+  v_logPiek_ = std::log(1.0/Mparam_.nbrowclust_)*(STK::Const::VectorX(Mparam_.nbrowclust_));
+  v_logRhol_ = std::log(1.0/Mparam_.nbcolclust_)*(STK::Const::VectorX(Mparam_.nbcolclust_));
 
 #ifdef COVERBOSE
   std::cout<<"Terminating ContingencyLBModel_mu_i_nu_j::randomInit()."<<"\n";
